flutter_tor library

Embedded Tor client for Flutter on iOS.

Classes

TorBridgeConfig
Tor bridge configuration.
TorBridgePresets
Predefined bridge configurations bundled with the package.
TorIos
Dart-side facade for the embedded Tor client running on iOS.
TorLogEvent
Log event coming from the native side (TorManager / TorIosPlugin / PT).
TorStatusEvent
Snapshot of the Tor client state delivered through TorIos.statusStream and TorIos.getStatus.

Enums

TorStatus
High-level state of the embedded Tor client.